from canvy.scripts.downloader import download
from canvy.scripts.grades import grades, grades_by_course

__all__ = ["download", "grades", "grades_by_course"]
